@@ -1,5 +1,5 @@
 ;;; recent-files.el --- Maintain menu of recently opened files.
-;;; $Header: /pack/xemacscvs/XEmacs/packages/xemacs-packages/edit-utils/recent-files.el,v 1.8 2003/06/18 17:22:35 viteno Exp $
+;;; $Header: /pack/xemacscvs/XEmacs/packages/xemacs-packages/edit-utils/recent-files.el,v 1.9 2004/11/08 02:38:42 ben Exp $
 ;;;
 ;;; Copyright (C) 1994, 1995 Juergen Nickelsen <nickel@cs.tu-berlin.de>
 ;;; Copyright (C) 2002 Ben Wing.
@@ -159,11 +159,11 @@
 ;;;
 ;;; `recent-files-non-permanent-submenu'
 ;;;    If this variable is non-nil, the non-permanent entries are put
-;;;    into a separate submenu of the recent-files menu. The default
+;;;    into a separate submenu of the recent-files menu. [[The default
 ;;;    is currently t, but probably should be nil, and we may change it
 ;;;    back. (You can set both `recent-files-permanent-submenu' and
 ;;;    `recent-files-non-permanent-submenu' to t to have both lists in
-;;;    separate submenus.)
+;;;    separate submenus.)]] Now defaults to nil.
 ;;;
 ;;; `recent-files-commands-submenu'
 ;;;    If this variable is non-nil, the commands if recent-files are
@@ -266,7 +266,7 @@ order."
   :type 'boolean
   :group 'recent-files-menu)
 
-(defcustom recent-files-non-permanent-submenu t
+(defcustom recent-files-non-permanent-submenu nil
   "*If non-nil, put the non-permanent entries of recent-files into a submenu."
   :type 'boolean
   :group 'recent-files-menu)
@@ -421,7 +421,7 @@ If the buffer has changed, the menu must be rebuilt.")
   "Return a string identifying the current version of recent-files.
 If called interactively, show it in the echo area."
   (interactive)
-  (let ((version "$Header: /pack/xemacscvs/XEmacs/packages/xemacs-packages/edit-utils/recent-files.el,v 1.8 2003/06/18 17:22:35 viteno Exp $"))
+  (let ((version "$Header: /pack/xemacscvs/XEmacs/packages/xemacs-packages/edit-utils/recent-files.el,v 1.9 2004/11/08 02:38:42 ben Exp $"))
     (if (interactive-p)
 	(message version)
       version)))
