@@ -529,7 +529,9 @@ This variable should not be set globally!  Commands that want to specify a
 default scrolling distance should just bind the variable `scroll-default-lines'
 temporarily.")
 
-(defvar scroll-command-groups nil
+(defvar scroll-command-groups '((scroll-up-one scroll-down-one)
+				(scrollbar-line-up scrollbar-line-down)
+				(scrollbar-page-up scrollbar-page-down))
   "The explicitly specified \"groups\" of \"in place\" scrolling commands.
 This variable should be set before or immediately after the \"in place\"
 scrolling package is loaded, and then not changed after that.
@@ -926,9 +928,10 @@ lines."
 ;;;
 ;;;
 
-(defun scroll-down (&optional lines)
-  "Scroll the text of the current window downward by LINES lines.  As a special
-case, when the current window is a minibuffer window, this command scrolls the
+(defun scroll-down (&optional lines window)
+  "Scroll the text of WINDOW downward by LINES lines.
+If WINDOW is nil, use the selected window -- but as a special case, when
+the current window is a minibuffer window, this command scrolls the
 `minibuffer-scroll-window' (which is usually the list of completions) if it
 exists, or otherwise the next window in the canonical ordering of windows.
 
@@ -947,15 +950,16 @@ current window is scrolled by nearly a complete windowful of text.
 Note that this command correctly handles cases in which `scroll-in-place' has a
 buffer-local value in the window to be scrolled.  That value is honored."
   (interactive "P")
-  (scroll-window (scroll-choose-window) lines -1))
+  (scroll-window (or window (scroll-choose-window)) lines -1))
 
 ;;;
 ;;;
 ;;;
 
-(defun scroll-up (&optional lines)
-  "Scroll the text of the current window upward by LINES lines.  As a special
-case, when the current window is a minibuffer window, this command scrolls the
+(defun scroll-up (&optional lines window)
+  "Scroll the text of WINDOW upward by LINES lines.
+If WINDOW is nil, use the selected window -- but as a special case, when
+the current window is a minibuffer window, this command scrolls the
 `minibuffer-scroll-window' (which is usually the list of completions) if it
 exists, or otherwise the next window in the canonical ordering of windows.
 
@@ -974,7 +978,7 @@ current window is scrolled by nearly a complete windowful of text.
 Note that this command correctly handles cases in which `scroll-in-place' has a
 buffer-local value in the window to be scrolled.  That value is honored."
   (interactive "P")
-  (scroll-window (scroll-choose-window) lines 1))
+  (scroll-window (or window (scroll-choose-window)) lines 1))
 
 ;;;
 ;;; NOTE that in the FSF GNU Emacs 19.26 version of `scroll-other-window-down',
